# Generated by Django 3.1.6 on 2023-02-13 02:14

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('bcmr', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='AuthToken',
            fields=[
                ('id', models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False)),
            ],
        ),
    ]
